import { defineStore } from 'pinia'

interface FilterValues {
  [x: string]: string[]
}

export const useTableSettingsStore = defineStore('tableSettings', () => {
  const route = useRoute()

  const savedColumnKeysMap = ref<{ [fullTableName: string]: string[] }>(
    JSON.parse(localStorage.getItem('savedColumnKeysMap') ?? '{}')
  )
  const saveColumnKeys = (columnKeys: string[] = [], tableName?: string) => {
    const fullTableName = route.path + (tableName ? `/${tableName}` : '')
    savedColumnKeysMap.value[fullTableName] = columnKeys
    localStorage.setItem(
      'savedColumnKeysMap',
      JSON.stringify(savedColumnKeysMap.value)
    )
  }

  const savedTableFilterValueMap = ref<{
    [fullTableName: string]: FilterValues
  }>(JSON.parse(localStorage.getItem('savedTableFilterValueMap') ?? '{}'))
  const saveTableFilterValues = (
    filterValues: FilterValues,
    tableName?: string
  ) => {
    const fullTableName = route.path + (tableName ? `/${tableName}` : '')
    savedTableFilterValueMap.value[fullTableName] = filterValues
    localStorage.setItem(
      'savedTableFilterValueMap',
      JSON.stringify(savedTableFilterValueMap.value)
    )
  }

  return {
    savedColumnKeysMap,
    saveColumnKeys,
    savedTableFilterValueMap,
    saveTableFilterValues,
  }
})
